#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 breakpoint
version:              0.1.4.0
visibility:           public
id:                   breakpoint-0.1.4.0-AskYxF1jPt0CWB3IqpaGFv
key:                  breakpoint-0.1.4.0-AskYxF1jPt0CWB3IqpaGFv
license:              MIT
maintainer:           aaronallen8455@gmail.com
author:               Aaron Allen
synopsis:             Set breakpoints using a GHC plugin
description:
    A plugin that allows you to set breakpoints for debugging purposes.

category:             Development
abi:                  a33cf7c19e3ef96639bb062604fecc24
exposed:              True
exposed-modules:
    Debug.Breakpoint Debug.Breakpoint.GhcFacade
    Debug.Breakpoint.TimerManager

hidden-modules:
    Debug.Breakpoint.Renamer Debug.Breakpoint.TypeChecker
    Debug.Breakpoint.TimerManager.Names

import-dirs:          /usr/lib/ghc-9.6.6/site-local/breakpoint-0.1.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/breakpoint-0.1.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/breakpoint-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-breakpoint
hs-libraries:         HSbreakpoint-0.1.4.0-AskYxF1jPt0CWB3IqpaGFv
depends:
    ansi-terminal-1.1-GHPRMJgDm8Q2nYFn6fdPQy base-4.18.2.1
    containers-0.6.7 deepseq-1.4.8.1 ghc-9.6.6 haskeline-0.8.2.1
    mtl-2.3.1 pretty-simple-4.1.4.0-1riV0fvYQgXI7SlWFbFYFq
    template-haskell-2.20.0.0 text-2.0.2 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-breakpoint/html/breakpoint.haddock
haddock-html:         /usr/share/doc/haskell-breakpoint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

